"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const colors_1 = require("colors");
const commander = require("commander");
const sh = require("shelljs");
const node_fs = require("fs");
/**
 * This is a CLI tool helps you do execute cmds per given folder. If you try to do the same
 * with a normal cd command, it will do it in the wrong folder. So this tool simply
 * navigates to the proper folders and does `your command`. That's it. #ez #boring
 */
commander
    .usage("<command> <directories...>")
    .arguments("<command> <directories...>")
    .parse(process.argv);
if (!commander.args.length) {
    console.error(colors_1.red("ERROR: No command given..\n"));
    throw new Error("No command found.");
}
const commandToExecute = commander.args.shift();
const directoriesToUse = commander.args;
const directoriesSucces = [];
const directoriesFailed = [];
if (!directoriesToUse.length) {
    console.error(colors_1.red("ERROR: No directories given..\n"));
    throw new Error("No directories found.");
}
commander.args.forEach((directory) => {
    try {
        node_fs.accessSync(directory, node_fs.constants.F_OK & node_fs.constants.R_OK);
    }
    catch (e) {
        console.log(colors_1.red(`Could not access path ${directory}, continuing...`));
        directoriesFailed.push(directory);
        return;
    }
    sh.pushd(directory);
    console.log(colors_1.yellow(`Executing command "${commandToExecute}" in: ${directory}`));
    sh.exec(commandToExecute);
    directoriesSucces.push(directory);
    sh.popd();
    console.log(colors_1.green("Done"));
});
if (directoriesSucces.length) {
    console.log();
    console.log(colors_1.green(`Done executing '${commandToExecute}' in the following directories:`));
    console.log(colors_1.green(directoriesSucces.join(", ")));
}
if (directoriesFailed.length) {
    console.log();
    console.log(colors_1.red(`Failed executing '${commandToExecute}' in the following directories:`));
    console.log(colors_1.green(directoriesSucces.join(", ")));
}
